@@ -33,6 +33,7 @@ class CentralReachCore(SitesCore):
 
         :return: Status of the login. True if successfully log in
         """
+        self.is_site_available = False
         self.browser.close_browser()
 
         if self.temp_folder:
@@ -63,9 +64,9 @@ class CentralReachCore(SitesCore):
                         raise CentralReachException('There was an unexpected problem signing in. If you keep seeing this, please contact CentralReach Support')
 
                 self.wait_element_and_refresh('//span[text()="Favorites"]', is_need_screenshot=False)
-                is_site_available = self.browser.does_page_contain_element('//span[text()="Favorites"]')
+                self.is_site_available = self.browser.does_page_contain_element('//span[text()="Favorites"]')
                 self.base_url: str = self.get_base_url(self.browser.get_location())
-                return is_site_available
+                return self.is_site_available
             except ScheduledMaintenance as ex:
                 raise ex
             except Exception as ex:
